@@ -193,6 +193,11 @@ fn main() -> QsvExitCode {
                 .deserialize()
         })
         .unwrap_or_else(|e| e.exit());
+
+    if util::load_dotenv().is_err() {
+        return QsvExitCode::Bad;
+    }
+
     if args.flag_list {
         wout!("Installed commands ({num_commands}):");
         wout!(
