@@ -35,6 +35,9 @@ const DEFAULT_FREEMEMORY_HEADROOM_PCT: u8 = 20;
 
 static ROW_COUNT: once_cell::sync::OnceCell<u64> = OnceCell::new();
 
+#[cfg(all(target_os = "linux", feature = "magic"))]
+pub const FIRST_CHUNK_BUFFER_SIZE: usize = 1024;
+
 pub type ByteString = Vec<u8>;
 
 #[inline]
@@ -132,17 +135,23 @@ pub fn version() -> String {
     enabled_features.push_str("foreach;");
     #[cfg(all(feature = "generate", not(feature = "lite")))]
     enabled_features.push_str("generate;");
+    #[cfg(all(target_os = "linux", feature = "magic"))]
+    {
+        enabled_features.push_str(format!("magic-{};", magic::version()).as_str());
+    }
 
     #[cfg(all(feature = "luau", not(feature = "lite")))]
     {
         let luau = mlua::Lua::new();
         match luau.load("return _VERSION").eval() {
             Ok(version_info) => {
-                if let mlua::Value::String(string_val) = version_info {
-                    enabled_features.push_str(&format!(
-                        "{};",
-                        string_val.to_str().unwrap_or("Luau - unknown version")
-                    ));
+                if let mlua::Value::String(luaustring_val) = version_info {
+                    let string_val = luaustring_val.to_str().unwrap_or("Luau - invalid version");
+                    if string_val == "Luau" {
+                        enabled_features.push_str("Luau - version not specified;");
+                    } else {
+                        enabled_features.push_str(&format!("{string_val};"));
+                    }
                 } else {
                     enabled_features.push_str("Luau - ?;");
                 }
@@ -1281,3 +1290,21 @@ pub fn get_filetype(path: &str) -> Result<String, CliError> {
 
     Ok(mime)
 }
+
+/// find out what kind of file we have using magic
+/// by sampling the FIRST_CHUNK_BUFFER_SIZE bytes of the file
+#[cfg(all(target_os = "linux", feature = "magic"))]
+pub fn sniff_filetype_from_buffer(in_buffer: &bytes::Bytes) -> Result<String, CliError> {
+    // We just want the mime type
+    let cookie = magic::Cookie::open(magic::CookieFlags::MIME_TYPE)?;
+
+    // Load libmagic's default database
+    cookie.load::<&str>(&[])?;
+
+    let mut buffer_wrk = bytes::BytesMut::with_capacity(FIRST_CHUNK_BUFFER_SIZE);
+    let buffer_len = std::cmp::min(in_buffer.len(), FIRST_CHUNK_BUFFER_SIZE);
+    buffer_wrk.extend_from_slice(&in_buffer[0..buffer_len]);
+    let mime = cookie.buffer(&buffer_wrk)?;
+
+    Ok(mime)
+}
